

/* point button: CursorA1 */
#define CursorA1_offo_width 6
#define CursorA1_offo_height 6
static unsigned char CursorA1_offo_label[] = {
  0x00, 0x00, 0x0c, 0x0c, 0x00, 0x00 };
static unsigned char CursorA1_offo_mask[] = {
  0x1e, 0x3f, 0x3f, 0x3f, 0x3f, 0x1e };
static ButtonLabel CursorA1_offo = {
  (unsigned char *)CursorA1_offo_label, (unsigned char *)CursorA1_offo_mask,
  CursorA1_offo_width, CursorA1_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  1, 0, 0, NULL };
#define CursorA1_offi_width 6
#define CursorA1_offi_height 6
static unsigned char CursorA1_offi_label[] = {
  0x00, 0x0c, 0x1e, 0x1e, 0x0c, 0x00 };
static unsigned char CursorA1_offi_mask[] = {
  0x1e, 0x3f, 0x3f, 0x3f, 0x3f, 0x1e };
static ButtonLabel CursorA1_offi = {
  (unsigned char *)CursorA1_offi_label, (unsigned char *)CursorA1_offi_mask,
  CursorA1_offi_width, CursorA1_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  1, 0, 0, NULL };
static ButtonLook CursorA1_look = {
  &CursorA1_offo, NULL, &CursorA1_offo, NULL,
  &CursorA1_offi, NULL, &CursorA1_offi, NULL };
static ButtonFeel CursorA1_feel = {
  "CursorA1", 2,
  { BTNMode, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 2, 256, 0, 0 } };
/* poly button: CursorA2 */
#define CursorA2_offo_width 21
#define CursorA2_offo_height 11
static unsigned char CursorA2_offo_label[] = {
  0x00, 0x00, 0x00, 0x02, 0x02, 0x08, 0x06, 0x05, 0x0c, 0x8a, 0x08, 0x0a,
  0x52, 0x10, 0x09, 0x22, 0xa0, 0x08, 0x02, 0x40, 0x08, 0x02, 0x00, 0x08,
  0x02, 0x00, 0x08, 0xfe, 0xff, 0x0f, 0x00, 0x00, 0x00 };
static unsigned char CursorA2_offo_mask[] = {
  0x07, 0x07, 0x1c, 0x8f, 0x0f, 0x1e, 0xdf, 0x1f, 0x1f, 0xff, 0xbf, 0x1f,
  0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xfd, 0x1f, 0xff, 0xff, 0x1f,
  0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f };
static ButtonLabel CursorA2_offo = {
  (unsigned char *)CursorA2_offo_label, (unsigned char *)CursorA2_offo_mask,
  CursorA2_offo_width, CursorA2_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  3, 0, 0, NULL };
#define CursorA2_offi_width 21
#define CursorA2_offi_height 11
static unsigned char CursorA2_offi_label[] = {
  0x00, 0x00, 0x00, 0x02, 0x02, 0x08, 0x06, 0x07, 0x0c, 0x8e, 0x0f, 0x0e,
  0xde, 0x1d, 0x0f, 0xfe, 0xb8, 0x0f, 0x76, 0xf0, 0x0d, 0x06, 0xe0, 0x0c,
  0xfe, 0xff, 0x0f, 0xfe, 0xff, 0x0f, 0x00, 0x00, 0x00 };
static unsigned char CursorA2_offi_mask[] = {
  0x07, 0x07, 0x1c, 0x8f, 0x0f, 0x1e, 0xdf, 0x1f, 0x1f, 0xff, 0xbf, 0x1f,
  0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xfd, 0x1f, 0xff, 0xff, 0x1f,
  0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f };
static ButtonLabel CursorA2_offi = {
  (unsigned char *)CursorA2_offi_label, (unsigned char *)CursorA2_offi_mask,
  CursorA2_offi_width, CursorA2_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  3, 0, 0, NULL };
static ButtonLook CursorA2_look = {
  &CursorA2_offo, NULL, &CursorA2_offo, NULL,
  &CursorA2_offi, NULL, &CursorA2_offi, NULL };
static ButtonFeel CursorA2_feel = {
  "CursorA2", 2,
  { BTNMode, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 2, 512, 0, 0 } };
/* circle button: CursorA3 */
#define CursorA3_offo_width 15
#define CursorA3_offo_height 15
static unsigned char CursorA3_offo_label[] = {
  0x00, 0x00, 0xe0, 0x03, 0x18, 0x0c, 0x04, 0x10, 0x04, 0x10, 0x02, 0x20,
  0x02, 0x20, 0x02, 0x20, 0x02, 0x20, 0x02, 0x20, 0x04, 0x10, 0x04, 0x10,
  0x18, 0x0c, 0xe0, 0x03, 0x00, 0x00 };
static unsigned char CursorA3_offo_mask[] = {
  0xf0, 0x07, 0xfc, 0x1f, 0xfe, 0x3f, 0xfe, 0x3f, 0x3f, 0x7e, 0x1f, 0x7c,
  0x0f, 0x78, 0x0f, 0x78, 0x0f, 0x78, 0x1f, 0x7c, 0x3f, 0x7e, 0xfe, 0x3f,
  0xfe, 0x3f, 0xfc, 0x1f, 0xf0, 0x07 };
static ButtonLabel CursorA3_offo = {
  (unsigned char *)CursorA3_offo_label, (unsigned char *)CursorA3_offo_mask,
  CursorA3_offo_width, CursorA3_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  2, 0, 0, NULL };
#define CursorA3_offi_width 15
#define CursorA3_offi_height 15
static unsigned char CursorA3_offi_label[] = {
  0x00, 0x00, 0xe0, 0x03, 0xf8, 0x0f, 0x1c, 0x1c, 0x0c, 0x18, 0x06, 0x30,
  0x06, 0x30, 0x06, 0x30, 0x06, 0x30, 0x06, 0x30, 0x0c, 0x18, 0x1c, 0x1c,
  0xf8, 0x0f, 0xe0, 0x03, 0x00, 0x00 };
static unsigned char CursorA3_offi_mask[] = {
  0xf0, 0x07, 0xfc, 0x1f, 0xfe, 0x3f, 0xfe, 0x3f, 0x3f, 0x7e, 0x1f, 0x7c,
  0x0f, 0x78, 0x0f, 0x78, 0x0f, 0x78, 0x1f, 0x7c, 0x3f, 0x7e, 0xfe, 0x3f,
  0xfe, 0x3f, 0xfc, 0x1f, 0xf0, 0x07 };
static ButtonLabel CursorA3_offi = {
  (unsigned char *)CursorA3_offi_label, (unsigned char *)CursorA3_offi_mask,
  CursorA3_offi_width, CursorA3_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  2, 0, 0, NULL };
static ButtonLook CursorA3_look = {
  &CursorA3_offo, NULL, &CursorA3_offo, NULL,
  &CursorA3_offi, NULL, &CursorA3_offi, NULL };
static ButtonFeel CursorA3_feel = {
  "CursorA3", 2,
  { BTNMode, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 2, 1024, 0, 0 } };
/* ellipse button: CursorA4 */
#define CursorA4_offo_width 23
#define CursorA4_offo_height 11
static unsigned char CursorA4_offo_label[] = {
  0x00, 0x00, 0x00, 0x80, 0xff, 0x00, 0x70, 0x00, 0x07, 0x0c, 0x00, 0x18,
  0x02, 0x00, 0x20, 0x02, 0x00, 0x20, 0x02, 0x00, 0x20, 0x0c, 0x00, 0x18,
  0x70, 0x00, 0x07, 0x80, 0xff, 0x00, 0x00, 0x00, 0x00 };
static unsigned char CursorA4_offo_mask[] = {
  0xc0, 0xff, 0x01, 0xf8, 0xff, 0x0f, 0xfe, 0xff, 0x3f, 0xff, 0xff, 0x7f,
  0xff, 0x80, 0x7f, 0x1f, 0x00, 0x7c, 0xff, 0x80, 0x7f, 0xff, 0xff, 0x7f,
  0xfe, 0xff, 0x3f, 0xf8, 0xff, 0x0f, 0xc0, 0xff, 0x01 };
static ButtonLabel CursorA4_offo = {
  (unsigned char *)CursorA4_offo_label, (unsigned char *)CursorA4_offo_mask,
  CursorA4_offo_width, CursorA4_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  3, 0, 0, NULL };
#define CursorA4_offi_width 23
#define CursorA4_offi_height 11
static unsigned char CursorA4_offi_label[] = {
  0x00, 0x00, 0x00, 0x80, 0xff, 0x00, 0xf0, 0xff, 0x07, 0x7c, 0x00, 0x1f,
  0x0e, 0x00, 0x38, 0x06, 0x00, 0x30, 0x0e, 0x00, 0x38, 0x7c, 0x00, 0x1f,
  0xf0, 0xff, 0x07, 0x80, 0xff, 0x00, 0x00, 0x00, 0x00 };
static unsigned char CursorA4_offi_mask[] = {
  0xc0, 0xff, 0x01, 0xf8, 0xff, 0x0f, 0xfe, 0xff, 0x3f, 0xff, 0xff, 0x7f,
  0xff, 0x80, 0x7f, 0x1f, 0x00, 0x7c, 0xff, 0x80, 0x7f, 0xff, 0xff, 0x7f,
  0xfe, 0xff, 0x3f, 0xf8, 0xff, 0x0f, 0xc0, 0xff, 0x01 };
static ButtonLabel CursorA4_offi = {
  (unsigned char *)CursorA4_offi_label, (unsigned char *)CursorA4_offi_mask,
  CursorA4_offi_width, CursorA4_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  3, 0, 0, NULL };
static ButtonLook CursorA4_look = {
  &CursorA4_offo, NULL, &CursorA4_offo, NULL,
  &CursorA4_offi, NULL, &CursorA4_offi, NULL };
static ButtonFeel CursorA4_feel = {
  "CursorA4", 2,
  { BTNMode, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 2, 1280, 0, 0 } };
/* box button: CursorA5 */
#define CursorA5_offo_width 21
#define CursorA5_offo_height 11
static unsigned char CursorA5_offo_label[] = {
  0x00, 0x00, 0x00, 0xfe, 0xff, 0x0f, 0x02, 0x00, 0x08, 0x02, 0x00, 0x08,
  0x02, 0x00, 0x08, 0x02, 0x00, 0x08, 0x02, 0x00, 0x08, 0x02, 0x00, 0x08,
  0x02, 0x00, 0x08, 0xfe, 0xff, 0x0f, 0x00, 0x00, 0x00 };
static unsigned char CursorA5_offo_mask[] = {
  0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f,
  0x0f, 0x00, 0x1e, 0x0f, 0x00, 0x1e, 0x0f, 0x00, 0x1e, 0xff, 0xff, 0x1f,
  0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f };
static ButtonLabel CursorA5_offo = {
  (unsigned char *)CursorA5_offo_label, (unsigned char *)CursorA5_offo_mask,
  CursorA5_offo_width, CursorA5_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  3, 0, 0, NULL };
#define CursorA5_offi_width 21
#define CursorA5_offi_height 11
static unsigned char CursorA5_offi_label[] = {
  0x00, 0x00, 0x00, 0xfe, 0xff, 0x0f, 0xfe, 0xff, 0x0f, 0x06, 0x00, 0x0c,
  0x06, 0x00, 0x0c, 0x06, 0x00, 0x0c, 0x06, 0x00, 0x0c, 0x06, 0x00, 0x0c,
  0xfe, 0xff, 0x0f, 0xfe, 0xff, 0x0f, 0x00, 0x00, 0x00 };
static unsigned char CursorA5_offi_mask[] = {
  0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f,
  0x0f, 0x00, 0x1e, 0x0f, 0x00, 0x1e, 0x0f, 0x00, 0x1e, 0xff, 0xff, 0x1f,
  0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f };
static ButtonLabel CursorA5_offi = {
  (unsigned char *)CursorA5_offi_label, (unsigned char *)CursorA5_offi_mask,
  CursorA5_offi_width, CursorA5_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  3, 0, 0, NULL };
static ButtonLook CursorA5_look = {
  &CursorA5_offo, NULL, &CursorA5_offo, NULL,
  &CursorA5_offi, NULL, &CursorA5_offi, NULL };
static ButtonFeel CursorA5_feel = {
  "CursorA5", 2,
  { BTNMode, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 2, 768, 0, 0 } };
/* ortho button: CursorA6 */
#define CursorA6_offo_width 15
#define CursorA6_offo_height 12
static unsigned char CursorA6_offo_label[] = {
  0x00, 0x00, 0x38, 0x1c, 0x44, 0x22, 0x82, 0x22, 0x82, 0x22, 0x82, 0x1c,
  0x82, 0x00, 0x82, 0x00, 0x82, 0x00, 0x44, 0x00, 0x38, 0x00, 0x00, 0x00 };
static unsigned char CursorA6_offo_mask[] = {
  0x7c, 0x3e, 0xfe, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xef, 0x7f, 0xef, 0x7f,
  0xef, 0x3f, 0xef, 0x01, 0xff, 0x01, 0xff, 0x01, 0xfe, 0x00, 0x7c, 0x00 };
static ButtonLabel CursorA6_offo = {
  (unsigned char *)CursorA6_offo_label, (unsigned char *)CursorA6_offo_mask,
  CursorA6_offo_width, CursorA6_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  2, 0, 0, NULL };
#define CursorA6_offi_width 15
#define CursorA6_offi_height 12
static unsigned char CursorA6_offi_label[] = {
  0x00, 0x00, 0x38, 0x1c, 0x6c, 0x36, 0xc6, 0x36, 0xc6, 0x36, 0xc6, 0x1c,
  0xc6, 0x00, 0xc6, 0x00, 0xc6, 0x00, 0x6c, 0x00, 0x38, 0x00, 0x00, 0x00 };
static unsigned char CursorA6_offi_mask[] = {
  0x7c, 0x3e, 0xfe, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xef, 0x7f, 0xef, 0x7f,
  0xef, 0x3f, 0xef, 0x01, 0xff, 0x01, 0xff, 0x01, 0xfe, 0x00, 0x7c, 0x00 };
static ButtonLabel CursorA6_offi = {
  (unsigned char *)CursorA6_offi_label, (unsigned char *)CursorA6_offi_mask,
  CursorA6_offi_width, CursorA6_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  2, 0, 0, NULL };
static ButtonLook CursorA6_look = {
  &CursorA6_offo, NULL, &CursorA6_offo, NULL,
  &CursorA6_offi, NULL, &CursorA6_offi, NULL };
static ButtonFeel CursorA6_feel = {
  "CursorA6", 2,
  { BTNFlash, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 2, 32768, 0, 0 } };
/* annuli button: CursorA7 */
#define CursorA7_offo_width 15
#define CursorA7_offo_height 15
static unsigned char CursorA7_offo_label[] = {
  0x00, 0x00, 0xfe, 0x3f, 0x02, 0x20, 0x02, 0x20, 0xf2, 0x27, 0x12, 0x24,
  0x12, 0x24, 0x12, 0x24, 0x12, 0x24, 0x12, 0x24, 0xf2, 0x27, 0x02, 0x20,
  0x02, 0x20, 0xfe, 0x3f, 0x00, 0x00 };
static unsigned char CursorA7_offo_mask[] = {
  0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f,
  0xff, 0x7f, 0x7f, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f,
  0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f };
static ButtonLabel CursorA7_offo = {
  (unsigned char *)CursorA7_offo_label, (unsigned char *)CursorA7_offo_mask,
  CursorA7_offo_width, CursorA7_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  2, 0, 0, NULL };
#define CursorA7_offi_width 15
#define CursorA7_offi_height 15
static unsigned char CursorA7_offi_label[] = {
  0x00, 0x00, 0xfe, 0x3f, 0xfe, 0x3f, 0x06, 0x30, 0xf6, 0x37, 0xf6, 0x37,
  0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0xf6, 0x37, 0xf6, 0x37, 0x06, 0x30,
  0xfe, 0x3f, 0xfe, 0x3f, 0x00, 0x00 };
static unsigned char CursorA7_offi_mask[] = {
  0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f,
  0xff, 0x7f, 0x7f, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f,
  0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f };
static ButtonLabel CursorA7_offi = {
  (unsigned char *)CursorA7_offi_label, (unsigned char *)CursorA7_offi_mask,
  CursorA7_offi_width, CursorA7_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  2, 0, 0, NULL };
static ButtonLook CursorA7_look = {
  &CursorA7_offo, NULL, &CursorA7_offo, NULL,
  &CursorA7_offi, NULL, &CursorA7_offi, NULL };
static ButtonFeel CursorA7_feel = {
  "CursorA7", 2,
  { BTNToggle, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 2, 4096, 0, 0 } };
/* arrow button: CursorA8 */
#define CursorA8_offo_width 16
#define CursorA8_offo_height 9
static unsigned char CursorA8_offo_label[] = {
  0x00, 0x00, 0x80, 0x01, 0x60, 0x00, 0x18, 0x00, 0xfe, 0x7f, 0x18, 0x00,
  0x60, 0x00, 0x80, 0x01, 0x00, 0x00 };
static unsigned char CursorA8_offo_mask[] = {
  0xc0, 0x03, 0xf0, 0x03, 0xfc, 0x03, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xfc, 0x03, 0xf0, 0x03, 0xc0, 0x03 };
static ButtonLabel CursorA8_offo = {
  (unsigned char *)CursorA8_offo_label, (unsigned char *)CursorA8_offo_mask,
  CursorA8_offo_width, CursorA8_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  2, 0, 0, NULL };
#define CursorA8_offi_width 16
#define CursorA8_offi_height 9
static unsigned char CursorA8_offi_label[] = {
  0x00, 0x00, 0x80, 0x01, 0xe0, 0x01, 0xf8, 0x00, 0xfe, 0x7f, 0xf8, 0x00,
  0xe0, 0x01, 0x80, 0x01, 0x00, 0x00 };
static unsigned char CursorA8_offi_mask[] = {
  0xc0, 0x03, 0xf0, 0x03, 0xfc, 0x03, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xfc, 0x03, 0xf0, 0x03, 0xc0, 0x03 };
static ButtonLabel CursorA8_offi = {
  (unsigned char *)CursorA8_offi_label, (unsigned char *)CursorA8_offi_mask,
  CursorA8_offi_width, CursorA8_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  2, 0, 0, NULL };
static ButtonLook CursorA8_look = {
  &CursorA8_offo, NULL, &CursorA8_offo, NULL,
  &CursorA8_offi, NULL, &CursorA8_offi, NULL };
static ButtonFeel CursorA8_feel = {
  "CursorA8", 2,
  { BTNMode, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 2, 1536, 0, 0 } };
/* abc button: CursorA9 */
#define CursorA9_offo_width 24
#define CursorA9_offo_height 14
static unsigned char CursorA9_offo_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x02, 0x00, 0x00, 0x02, 0x00,
  0x1c, 0x1a, 0x38, 0x22, 0x26, 0x44, 0x30, 0x42, 0x02, 0x2c, 0x42, 0x02,
  0x22, 0x42, 0x02, 0x22, 0x26, 0x44, 0x5c, 0x1a, 0x38, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static unsigned char CursorA9_offo_mask[] = {
  0x00, 0x07, 0x00, 0x00, 0x07, 0x00, 0x00, 0x07, 0x00, 0x3e, 0x3f, 0x7c,
  0x7f, 0x7f, 0xfe, 0x7f, 0xff, 0xff, 0x7f, 0xff, 0xef, 0x7f, 0xe7, 0x07,
  0x7f, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xfe, 0xfe, 0x3f, 0x7c,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int CursorA9_offo_breaks[] = { 8, 16, 24 };
static ButtonLabel CursorA9_offo = {
  (unsigned char *)CursorA9_offo_label, (unsigned char *)CursorA9_offo_mask,
  CursorA9_offo_width, CursorA9_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  3, 3, 0, CursorA9_offo_breaks };
#define CursorA9_offi_width 24
#define CursorA9_offi_height 14
static unsigned char CursorA9_offi_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x03, 0x00, 0x00, 0x03, 0x00,
  0x1e, 0x3f, 0x3e, 0x33, 0x63, 0x63, 0x30, 0x63, 0x03, 0x3e, 0x63, 0x03,
  0x33, 0x63, 0x63, 0x33, 0x63, 0x63, 0x6e, 0x3f, 0x3e, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static unsigned char CursorA9_offi_mask[] = {
  0x80, 0x07, 0x00, 0x80, 0x07, 0x00, 0x80, 0x07, 0x00, 0xbf, 0x7f, 0x7f,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xf7, 0xff, 0xf7, 0xf7,
  0xff, 0xf7, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0x7f,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int CursorA9_offi_breaks[] = { 8, 16, 24 };
static ButtonLabel CursorA9_offi = {
  (unsigned char *)CursorA9_offi_label, (unsigned char *)CursorA9_offi_mask,
  CursorA9_offi_width, CursorA9_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  3, 3, 0, CursorA9_offi_breaks };
static ButtonLook CursorA9_look = {
  &CursorA9_offo, NULL, &CursorA9_offo, NULL,
  &CursorA9_offi, NULL, &CursorA9_offi, NULL };
static ButtonFeel CursorA9_feel = {
  "CursorA9", 2,
  { BTNMode, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 2, 1792, 0, 0 } };
static ButtonSpec CursorA[] = {
  { &CursorA1_look, &CursorA1_feel },
  { &CursorA2_look, &CursorA2_feel },
  { &CursorA3_look, &CursorA3_feel },
  { &CursorA4_look, &CursorA4_feel },
  { &CursorA5_look, &CursorA5_feel },
  { &CursorA6_look, &CursorA6_feel },
  { &CursorA7_look, &CursorA7_feel },
  { &CursorA8_look, &CursorA8_feel },
  { &CursorA9_look, &CursorA9_feel } };
static BoxGeometry CursorA_geo = 
  { 0, 9, 9, 1, 10.285710, 1.000000, 0.000000, 0.000000, 0, 1 };

/* region button: CursorB10 */
#define CursorB10_offo_width 42
#define CursorB10_offo_height 14
static unsigned char CursorB10_offo_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x1a, 0x06, 0x96, 0x70, 0xe8, 0x00, 0x06, 0x09, 0x99, 0x88, 0x18, 0x01,
  0x82, 0x90, 0x90, 0x04, 0x09, 0x01, 0x82, 0x9f, 0x90, 0x04, 0x09, 0x01,
  0x82, 0x80, 0x90, 0x04, 0x09, 0x01, 0x02, 0x11, 0x99, 0x88, 0x08, 0x01,
  0x02, 0x0e, 0x96, 0x70, 0x08, 0x01, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00,
  0x00, 0x80, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0f, 0x00, 0x00, 0x00 };
static unsigned char CursorB10_offo_mask[] = {
  0x00, 0x00, 0xc0, 0x01, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x01, 0x00, 0x00,
  0x00, 0x00, 0xc0, 0x01, 0x00, 0x00, 0x3f, 0x0f, 0xff, 0xf9, 0xfc, 0x01,
  0xbf, 0x9f, 0xff, 0xfd, 0xfd, 0x03, 0xff, 0xff, 0xff, 0xff, 0xff, 0x03,
  0xcf, 0xff, 0xff, 0xdf, 0xbf, 0x03, 0xc7, 0xff, 0xf9, 0x8f, 0x9f, 0x03,
  0xc7, 0xff, 0xff, 0xdf, 0x9f, 0x03, 0xc7, 0xff, 0xff, 0xff, 0x9f, 0x03,
  0x87, 0xbf, 0xff, 0xfd, 0x9d, 0x03, 0x07, 0xdf, 0xff, 0xf9, 0x9c, 0x03,
  0x00, 0xc0, 0x3f, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x3f, 0x00, 0x00, 0x00 };
static int CursorB10_offo_breaks[] = { 6, 14, 22, 25, 34, 42 };
static ButtonLabel CursorB10_offo = {
  (unsigned char *)CursorB10_offo_label, (unsigned char *)CursorB10_offo_mask,
  CursorB10_offo_width, CursorB10_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  6, 6, 0, CursorB10_offo_breaks };
#define CursorB10_offi_width 41
#define CursorB10_offi_height 14
static unsigned char CursorB10_offi_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x00, 0x00, 0x00,
  0x00, 0x00, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x9f, 0x8f, 0xdf, 0x7c, 0x7e, 0x00, 0xdb, 0xd8, 0xd8, 0xc6, 0xc6, 0x00,
  0xc3, 0xd8, 0xd8, 0xc6, 0xc6, 0x00, 0xc3, 0xdf, 0xd8, 0xc6, 0xc6, 0x00,
  0xc3, 0xc0, 0xd8, 0xc6, 0xc6, 0x00, 0xc3, 0xd8, 0xd8, 0xc6, 0xc6, 0x00,
  0x83, 0x8f, 0xdf, 0x7c, 0xc6, 0x00, 0x00, 0x00, 0x18, 0x00, 0x00, 0x00,
  0x00, 0xc0, 0x18, 0x00, 0x00, 0x00, 0x00, 0x80, 0x0f, 0x00, 0x00, 0x00 };
static unsigned char CursorB10_offi_mask[] = {
  0x00, 0x00, 0xe0, 0x01, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x01, 0x00, 0x00,
  0x00, 0x00, 0xe0, 0x01, 0x00, 0x00, 0xff, 0xdf, 0xff, 0xff, 0xff, 0x00,
  0xff, 0xff, 0xff, 0xff, 0xff, 0x01, 0xff, 0xff, 0xff, 0xff, 0xff, 0x01,
  0xff, 0xff, 0xfd, 0xef, 0xef, 0x01, 0xe7, 0xff, 0xfd, 0xef, 0xef, 0x01,
  0xe7, 0xff, 0xfd, 0xef, 0xef, 0x01, 0xe7, 0xff, 0xff, 0xff, 0xef, 0x01,
  0xe7, 0xff, 0xff, 0xff, 0xef, 0x01, 0xc7, 0xff, 0xff, 0xff, 0xef, 0x01,
  0x00, 0xe0, 0x3f, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x3f, 0x00, 0x00, 0x00 };
static int CursorB10_offi_breaks[] = { 6, 14, 22, 25, 33, 41 };
static ButtonLabel CursorB10_offi = {
  (unsigned char *)CursorB10_offi_label, (unsigned char *)CursorB10_offi_mask,
  CursorB10_offi_width, CursorB10_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  6, 6, 0, CursorB10_offi_breaks };
static ButtonLook CursorB10_look = {
  &CursorB10_offo, NULL, &CursorB10_offo, NULL,
  &CursorB10_offi, NULL, &CursorB10_offi, NULL };
static ButtonFeel CursorB10_feel = {
  "CursorB10", 2,
  { BTNToggle, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 6, 0, 0, 0 } };
static ButtonSpec CursorB[] = {
  { &CursorB10_look, &CursorB10_feel } };
static BoxGeometry CursorB_geo = 
  { 0, 1, 1, 1, 8.000000, 1.000000, 0.875000, 0.000000, 0, 1 };

void MakeCursorPanel ( box, parent, gc, visual, background )
     BoxParent *parent;
     ButtonBox box[2];
     GC gc;
     Visual *visual;
     unsigned long background;
{
  box[0] = MakeButtonBox(&parent[1], gc, visual, background,
			 &CursorA_geo, CursorA, 0);
  box[1] = MakeButtonBox(&parent[1], gc, visual, background,
			 &CursorB_geo, CursorB, 0);
  JoinMenus (box[0], box[1]);
}
